summaryrefslogtreecommitdiffstats
path: root/webkit/plugins/ppapi/ppb_video_decoder_impl.cc
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/plugins/ppapi/ppb_video_decoder_impl.cc')
-rw-r--r--webkit/plugins/ppapi/ppb_video_decoder_impl.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/webkit/plugins/ppapi/ppb_video_decoder_impl.cc b/webkit/plugins/ppapi/ppb_video_decoder_impl.cc
index 9d34734..ac4a82b 100644
--- a/webkit/plugins/ppapi/ppb_video_decoder_impl.cc
+++ b/webkit/plugins/ppapi/ppb_video_decoder_impl.cc
@@ -45,12 +45,12 @@ PPB_VideoDecoder_Impl::PPB_VideoDecoder_Impl(PP_Instance instance)
PPB_VideoDecoder_Impl::~PPB_VideoDecoder_Impl() {
}
-// Convert PP_VideoDecoder_Profile to media::VideoDecodeAccelerator::Profile.
-static media::VideoDecodeAccelerator::Profile PPToMediaProfile(
+// Convert PP_VideoDecoder_Profile to media::VideoCodecProfile.
+static media::VideoCodecProfile PPToMediaProfile(
const PP_VideoDecoder_Profile pp_profile) {
// TODO(fischman,vrk): this assumes the enum values in the two Profile types
// match up exactly. Add a COMPILE_ASSERT for this somewhere.
- return static_cast<media::VideoDecodeAccelerator::Profile>(pp_profile);
+ return static_cast<media::VideoCodecProfile>(pp_profile);
}
// static